---
output:
  pdf_document: default
  html_document: default
---

# Tourism and Recreation  

People value the ability to enjoy and use coastal areas for outdoors experiences. The ability to do so can be limited by lack of tourism infrastructure, contaminated waters at beaches, and lack of coastal access points. Accessing coastal areas for non extractive purposes is important to many people, including locals who build communities around beach usage, and tourists who generally aggregate near beaches. 

This goal aims to capture the number of people, and the quality of their experience, visiting coastal and marine areas and attractions. Although coastal tourism industries can be important contributors to coastal economies, the tourism and recreation goal is assessed separately from its economic benefits, which are reported in the coastal livelihoods and economies goal. We include three components for this goal: number of jobs in the tourism sector, the number of days with beach closures from contaminants, and frequency of access points along the coast. This goal scores highest when tourism is abundant and the ability to consistently access the coast is high. This goal is not about the revenue or livelihoods that are generated by tourism and recreation (that is captured in the livelihoods & economies goal) but instead captures the value that people have for experiencing and enjoying coastal areas. 

The Tourism & Recreation goal status ($TR$) is equal to the *geometric mean* of the three layer scores: **coastal access** ($c$), **beach closures** ($b$) and **jobs in tourism** ($j$) for each region ($i$) and year ($t$). This goal is not assessed for the four offshore regions since tourism and recreation is nearly always limited to the coastal region.

$$ TR{i,t} =100*\sqrt[3]{c_{i,t}+b_{i,t}+j_{i,t}}$$


## Goal layers

----

### Beach closures

**Data description**   
This layer is derived from the  U.S. Environmental Protection Agency (EPA)  [BEach Advisory and Closing Online Notification (BEACON) dataset](https://watersgeo.epa.gov/beacon2). The most recent version (2.0) was used. The beach action (advisory and closures) dataset from the BEACON database was downloaded for all states in the assessment (ME, NY, NH, MA, RI, CT). This data contains beach-level information for closures including the length of the closure and the reson for closure. The Beach Days dataset was also downloaded and used to get an estimate of length of swim seasons.

**Methods summary**    
We used the proportion of the swim season with beaches closed due to pathogens in the water as a proxy for the impact of pathogens in coastal waters (Clean Waters) and also as a measure of limited recreation access (Tourism & Recreation). First we looked at the average length of swim season by state using the Beach Days dataset. The season length varied from 97 to 104 so we set a single reference point as 100 days free of closures, representing the average length of the swimming season for the region.

State | Average # of beach days
------|---------------------
CT|98
MA|101
ME|99.3
NH|97.3
RI|97.7
NY|104

Next we looked at beach closures by region. The beach action dataset identified the reason why a beach was closed which for the Northeast included elevated bacteria, sewage or runoff from rainfall. For each beach the total number of days closed due to these reasons was calculated and then divided by the reference point of 100 days to calculate the proportion of the season each beach was closed. This was then averaged across each region and done for every year 2005 to 2017. 

**Tourism & Recreation goal layer**  
The beach closures data layer used in the Tourism & Recreation goal had values for each region and year set equal to the average proportion of a regions swim season with beaches open, or the inverse of the pressure layer, where higher values indicate higher score.

**Gapfilling:**   
None needed

----

### Coastal access

**Data description(s):**   
This layer is derived from NOAA's Office of Response and Restoration's Environmental Sensitivity Index data. These maps were created to identify coastal resources that could be at risk if an oil spill were to occur. These include biological resources, sensitive habitats and human-use areas, which is the category we used to measure coastal access. Tee data was manually downloaded from the ESI site (https://response.restoration.noaa.gov/esi_download) for each state in the Northeast in August of 2019. The geospatial files provide point data. The data availability varied from different time periods between 2001 and 2016, but we combine all datasets as a single representative layer, therefore the time does not play a role in the final coastal access layer.  

**Methods summary:** 

The spatial information for each state was filtered to only those points that were of human use/interest. The reported point types varied from state to state, but overall encompassed the following which we included as coastal access points:

*Historical Site, Beach, Campground, Access Point, Boat Ramp, Marina, Ferry, Port, Access Point, Park, National Landmark, Surfing*

After removing all points not within these categories, a 1 mile buffer was applied to all points, since we were interested in measuring access points every mile of the coast. The total land area covered by this buffered point layer was calculated and compared to the total area of the 1 mile inland coastal shapefile. This allowed for comparison of how much of the 1 mile coastal strip was covered by an access point.

**Tourism & Recreation goal layer**    
The score for each region was equal to the total area covered by coastal access points divided by the total area of the 1 mile inland buffer. A score of 1 indicates that there is a coastal access point every mile of the coast.

**Gapfilling:**  
Since there was not updated temporal data, this static layer was used for all years 2005 - 2016. There was no spatial gapfilling. 

----

### Tourism job growth

**Layer type(s):** Tourism & Recreation goal layer  

**Data description(s):**   
NOAA's Economics: National Ocean Watch (ENOW) data provides economic data relevant to ocean sectors at a county level for years 2005 - 2016. Ocean sectors include Living Resources, Marine Construction, Transportation, Ship & Boat Building, Tourism & Recreation, and Offshore Mineral Extraction. ENOW data on annual employment was provided by the National Ocean Economics Program (NOEP) by county and ocean sector. For this layer, the employment data was filtered to just the Tourism & Recreation sector.

**Methods summary:** The data was provided by county and also as state-wide totals. From the data we selected employment numbers from the "Tourism & Recreation" sector.

We compared aggregated county data to the state-wide totals and found differences between these two data series. This could be explained by suppressed data at the county level that is included in the state-wide totals. By comparing the absolute values and the temporal trends of the county-aggregated and state-wide totals we made decisions about what data series to use, either the county-level or state-wide totals. For this data series, the state level totals were used for all regions. Annual employment in the tourism and recreation sector is compared to the mean number of jobs in the tourism sector over the previous 3 years.

**Tourism goal layer**  
Each region's annual number of jobs in the tourism sector ($j$) is compared to the average number of jobs in tourism over the previous three years. If the the region shows an increase in the number of jobs compared to the previous three years, the region receives a score ($s$) of 1, otherwise the region score is scaled so that a loss of 25% of jobs in the tourism sector compared to the previous 3 years results in a score of 0. This reference point ($ref_{min}$ = 0.25) is equal to what was experienced during the Great Depression (across all sectors).

$$T=\frac{j_t}{\frac{1}{3}(j_{t-1} + j_{t-2} + j_{t-3})}-1$$

Where $T$ is the tourism job growth rate,

$$ s_{i,t} = \begin{cases} 1 ,& T >= 0,\\
\frac{T - ref_{min}}{0 - ref_{min}},& T < 0
\end{cases}$$

**Gapfilling:**  
The first three years of the time series, 2005-2007, were gapfilled with data from 2008 since growth rate was calculated by comparing to the previous three year mean. Since the dataset ends in 2016, these values are carried forward to 2017. Connecticut was missing data for 2008. This was gapfilled using a simple linear interpolation of employment numbers between the years 2007 and 2009.

----

#### References:

National Ocean Economics Program. Ocean Economic Data by Sector & Industry., ONLINE. 2012. Available: http://www.OceanEconomics.org/Market/oceanEcon.asp [9 May 2019]

National Oceanic and Atmospheric Administration (NOAA). Economics: National Ocean Watch (ENOW) Data. Based on data from the Bureau of Labor Statistics and the Bureau of Economic Analysis. Charleston, SC: NOAA Office for Coastal Management.

U.S. Environmental Protection Agency, BEACON 2.0 (Beach Advisory and Closing Online Notification). (2019). Beach closures. Retrieved from https://watersgeo.epa.gov/beacon2/

National Oceanic Atmospheric Administration/Office of Response and Restoration. (2017).  Download ESI Maps and GIS Data.  NOAA/NOS Office of Response and Restoration, Seattle, WA. https://response.restoration.noaa.gov/esi_download
